@@ -3,6 +3,7 @@ context("read_families")
 # skip tests because they take too much time
 skip_if(Sys.getenv("TEST_ONE") != "")
 testthat::skip_on_cran()
+testthat::skip_if_not_installed("arrow")
 
 
 # Reading the data -----------------------
@@ -26,7 +27,7 @@ test_that("read_families", {
 
   # add labels
   test4 <- read_families(add_labels = 'pt', columns = c('abbrev_state', 'V1004'))
-  test4 <- test4 |> filter(abbrev_state == 'CE') |> as.data.frame()
+  test4 <- test4 |> dplyr::filter(abbrev_state == 'CE') |> as.data.frame()
   testthat::expect_true('Fortaleza' %in% test4$V1004)
 
 })
