@@ -3,6 +3,7 @@ context("read_population")
 # skip tests because they take too much time
 skip_if(Sys.getenv("TEST_ONE") != "")
 testthat::skip_on_cran()
+testthat::skip_if_not_installed("arrow")
 
 
 # Reading the data -----------------------
@@ -58,7 +59,7 @@ test_that("read_population", {
 
   # add labels
   test4 <- read_population(add_labels = 'pt', columns = c('abbrev_state', 'V1005'))
-  test4 <- test4 |> filter(abbrev_state == 'CE') |> as.data.frame()
+  test4 <- test4 |> dplyr::filter(abbrev_state == 'CE') |> as.data.frame()
   testthat::expect_true(paste('\u00c1rea urbanizada') %in% test4$V1005)
 
 })
